import axios from 'axios';
const cheerio = require('cheerio')
import { downloadImage } from "../share/tools"
import { getCollection } from '../lib/mongodb';
import { FetchType } from '..';
// 要抓取的网页 URL

async function getPageData(url: string, name: string) {
  try {

    const { data } = await axios.get(url);
    const $ = cheerio.load(data);
    const element = $(`a[title="${name}"]`)
    return element.attr('href')

  } catch (error) {
    console.error('Error fetching data:', error);

  }
}
export async function queryListData(list: FetchType[]) {
  const col = await getCollection('link');
  await col.deleteMany({})
  for (const item of list) {
    await fetchData(item)
  }
}
export async function fetchData({ typeId, name: typeName, url, hasSubType = false }: FetchType) {
  try {
    // 请求目标页面
    const { data } = await axios.get(url);

    // 使用 cheerio 加载 HTML

    const $ = cheerio.load(data);

    // 提取工具卡片数据
    const toolsData = [] as any[];
    const length = $('.url-card').length
    let i = 0
    for (const element of $('.url-card')) {
      const subTitle = $(element).parent().prev().find('h4').text().trim();
      const name = $(element).find('.url-info strong').text().trim();
      const tempLink = $(element).find('a').attr('href') as string;
      const description = $(element).find('.url-info p').text().trim();
      const _id = $(element).attr('data-id');
      const _originLink = $(element).find('img').attr('data-src');
      let link = tempLink


      console.log(subTitle);

      if (tempLink.startsWith('https://ai-bot')) {
        link = await getPageData(tempLink, name) || ''

      }
      // 假设工具的类别是固定的，比如 "AI写作工具"
      const type = typeId;
      const priority = 1;  // 根据索引来定义优先级
      const addTime = Date.now() / 1000;
      const logoLink = await downloadImage(_originLink)
      // console.log(logoLink);
      // const logoLink = ''
      // 将提取的数据转换为 Link 类型
      const toolData = {
        name,
        link,
        description,
        _id,
        type,
        priority,
        logoLink,
        addTime,
        subLinkType: hasSubType ? [subTitle] : undefined
      };
      if (hasSubType) {
        if (toolsData.findIndex(val => val.name === name) !== -1) {
          console.log('发现相同的name:' + name);

          toolsData[toolsData.findIndex(val => val.name === name)].subLinkType.push(subTitle)
        } else {
          toolsData.push(toolData);

        }
      } else {
        toolsData.push(toolData);
      }

      i++
      console.clear()
      console.log(`正在爬取${typeName + ',' + subTitle || ''}类别的数据，共${length}条数据`);

      console.log(`${typeName}：进度：${i}/${length}`);

    }
    console.log(toolsData);

    const col = await getCollection('link');
    col.insertMany(toolsData);
    console.log('数据插入成功');
  } catch (error) {
    console.error('Error fetching data:', error);
  }
}


